<?php

/*
* Mail expiration plugin
* Copyright 2005-2006 Florian Daeumling <jam@qv90.de>, Jaballa Software
* Licensed under the GNU GPL. For full terms see the file COPYING.
*/

function squirrelmail_plugin_init_expire() {
    global $squirrelmail_plugin_hooks;

    $squirrelmail_plugin_hooks['loading_prefs']['expire'] = 'expire_prefs';
    $squirrelmail_plugin_hooks['folders_bottom']['expire'] = 'expire_options';
    $squirrelmail_plugin_hooks['rename_or_delete_folder']['expire'] = 'expire_check';
}

function expire_prefs() {
    include_once (SM_PATH . 'plugins/expire/functions.php');

    expire_defaults();
}

function expire_options() {
    include_once (SM_PATH . 'plugins/expire/functions.php');

    expire_menu();
}

function expire_check($parms) {
    include_once (SM_PATH . 'plugins/expire/functions.php');

    expire_folder($parms);
}

function expire_version() {
    return '1.3.1';
}

?>
